# Release Notes

This page tracks the recent direction of the project.

## v0.18

Focus:

- thinner front door
- pattern-first API
- provider-bound skill organisms
- attachable telemetry

Related writing:

- [Medium: Operon v0.18](https://medium.com/@coredipper/operon-v0-18-the-point-where-it-started-feeling-usable-b284d7b7317f)
- [Blog: Operon v0.18](https://banu.be/blog/operon-v018-pattern-first-skills/)

## v0.17

Focus:

- epistemic topology
- architecture-level analysis
- practical comparison to Kim et al.

Related writing:

- [Blog: Operon v0.17](https://banu.be/blog/operon-v017-epistemic-topology/)
